@@ -6,6 +6,7 @@
 #' @import lattice
 #' @importFrom utils tail
 #' @importFrom latticeExtra useOuterStrips
+#'
 #' @param x Formula object to plot. The formula is of the form y ~ x | g1 + g2 +
 #'   ..., indicating that plots of y (on the y-axis) versus x (on the x-axis)
 #'   should be produced conditional on the variables g1, g2.
@@ -19,8 +20,6 @@
 #' @param cex Number indicating the magnification of plotting character.
 #' @param gap Number indicating spacing between panels.
 #' @param target Value specifying a target line to plot.
-#' @param direction Value indication direction of improvement, 0 (down) or 1
-#'   (up).
 #' @param xpad Number specifying the fraction by which to extend the x-axis in
 #'   order to make space for the median label.
 #' @param ... Further arguments to xyplot.
@@ -65,27 +64,22 @@ trc <- function(x,
                 cex    = 0.7,
                 gap    = 0.5,
                 target = NA,
-                direction = NULL,
                 ...) {
-#   col1     <- rgb(093, 165, 218, maxColorValue = 255)
-#   col2     <- rgb(223, 092, 036, maxColorValue = 255)
-#   col3     <- rgb(140, 140, 140, maxColorValue = 255)
-  col1            <- rgb(093, 165, 218, maxColorValue = 255) # blue
-  col2            <- rgb(140, 140, 140, maxColorValue = 255) # grey
-  col3            <- rgb(005, 151, 072, maxColorValue = 255) # green
-  col4            <- rgb(255, 165, 000, maxColorValue = 255) # yellow
-  col5            <- rgb(241, 088, 084, maxColorValue = 255) # red
-
+  col1     <- rgb(093, 165, 218, maxColorValue = 255) # blue
+  col2     <- rgb(140, 140, 140, maxColorValue = 255) # grey
+  col3     <- rgb(005, 151, 072, maxColorValue = 255) # green
+  col4     <- rgb(241, 088, 084, maxColorValue = 255) # red
   axiscol  <- 'grey50'
   stripcol <- 'grey90'
   stripbor <- 'grey90'
-
   chart    <- match.arg(chart)
-  strip    <- strip.custom(bg = stripcol)
-  # strip    <- strip.custom(bg = col)
+  strip    <- strip.custom(par.strip.text = list(cex = 0.8))
   par      <- list(axis.line = list(col = stripcol),
                    strip.border = list(col = stripbor),
-                   par.main.text = list(cex = 1.25,
+                   strip.background = list(col = stripcol),
+                   par.xlab.text = list(cex = 0.9),
+                   par.ylab.text = list(cex = 0.9),
+                   par.main.text = list(cex = 1,
                                         font = 1,
                                         just = 'left',
                                         x = grid::unit(3, 'lines')))
@@ -97,7 +91,6 @@ trc <- function(x,
 
   # Scale axes
   prepanel <- function(x, y, ...) {
-    # qic <- qic(y, chart = chart, plot.chart = FALSE, ...)
     qic <- qic(y, chart = chart, plot = FALSE, ...)
     list(xlim = range(min(x), max(extendrange(x, f = xpad))),
          ylim = range(qic$y, qic$lcl, qic$ucl, target, na.rm = T))
@@ -105,58 +98,56 @@ trc <- function(x,
 
   # Setup plot
   panel <- function(x, y, ...) {
-    # qic <- qic(y, chart = chart, plot.chart = FALSE, ...)
     qic <- qic(y, chart = chart, plot = FALSE, ...)
     signal <- qic$runs.test
 
-    if(signal) {
-      col <- col4
-      lty <- 5
-    } else {
-      col <- col2
-      lty <- 1
-    }
-
-    # colour center line according to type of variation and target (red-amber-green)
+    # colour center line according to type of variation and target
     lty <- 1
     col <- col2
-    m <- ifelse(direction, 1, -1)
     if(signal) {
       lty <- 5
       col <- col4
-    } else if(!is.na(target) & !is.null(direction)) {
-      col <- ifelse((target - tail(qic$cl, 1)) * m > 0, col5, col3)
     }
 
-    panel.lines(x, qic$cl, col = col, lty = lty, lwd = 1)
-    panel.lines(x, qic$ucl, col = col2, lwd = 1)
-    panel.lines(x, qic$lcl, col = col2, lwd = 1)
-    panel.lines(x, target, col = col2, lty = 3)
-    panel.points(x, y, type = 'o', pch = pch, col = col1, lwd = 2.5, cex = cex)
-    panel.text(x = max(x), y = qic$cl,
-               labels = sround(qic$cl, dec), #rounded_labels,
+    panel.lines(x, qic$cl,
+                col = col,
+                lty = lty)
+    panel.lines(x, qic$ucl,
+                col = col2)
+    panel.lines(x, qic$lcl,
+                col = col2)
+    panel.lines(x, target,
+                col = col3,
+                lty = 3)
+    panel.points(x, y,
+                 type = 'o',
+                 pch = pch,
+                 col = col1,
+                 lwd = 2.5,
+                 cex = cex)
+    panel.points(x[qic$signal], y[qic$signal],
+                 col = col4,
+                 cex = cex * 1.5,
+                 pch = pch)
+    panel.text(x = max(x), y = max(qic$cl),
+               labels = sround(max(qic$cl), dec),
                cex = 0.8,
                pos = 4)
-
     panel.text(x = max(x), y = target,
                labels = target,
                cex = 0.8,
                pos = 4)
     panel.xyplot(x, y, ...)
-    panel.points(x[qic$signal], y[qic$signal],
-                 col = col4,
-                 cex = cex * 1.5,
-                 pch = pch)
   }
 
   # Create plot
   p <- xyplot(x,
               type         = 'n',
-              scales       = scales,
-              prepanel     = prepanel,
               panel        = panel,
-              col          = col2,
+              prepanel     = prepanel,
+              scales       = scales,
               strip        = strip,
+              col          = col2,
               par.settings = par,
               between      = list(x = gap, y = gap),
               ...)
